@@ -15,6 +15,8 @@ import sys
 
 from pathlib import Path
 from typing import Any
+from typing import Dict
+from typing import Optional
 
 import numpy as np
 import plotille as plt
@@ -22,7 +24,7 @@ import plotille as plt
 from . import __version__
 
 
-def log(msg: str, mode: int = None) -> None:
+def log(msg: str, mode: Optional[int] = None) -> None:
     """Print messages to display.
 
     Parameters
@@ -38,14 +40,14 @@ def log(msg: str, mode: int = None) -> None:
         print(msg)
 
 
-def load_data(fname: str, args: dict) -> np.ndarray:
+def load_data(fname: str, args: Dict[str, Any]) -> np.ndarray:
     """Load data via np.genfromtxt.
 
     Parameters
     ----------
     fname : str
         Filename to load via np.genfromtxt.
-    args : dict
+    args : Dict[str, Any]
         Dictionary of the keywords and values from the parser.
 
     Returns
@@ -88,10 +90,12 @@ def plot_plot(fig: Any, x: np.ndarray, y: np.ndarray, label: str) -> Any:
         Returns the function itself for a smaller (n-1) float-array (y) until it is an
         1D-array.
     """
-    fig.plot(x, y[:, 0], label=label)
-    if y.shape[1] == 1:
-        return fig
-    return plot_plot(fig, x, y[:, 1:], label=label)
+    if len(y.shape) > 1:
+        for i in range(y.shape[1]):
+            fig.plot(x, y[:, i], label=label)
+    else:
+        fig.plot(x, y, label=label)
+    return fig
 
 
 def plot_scatter(fig, x: np.ndarray, y: np.ndarray, label: str):
@@ -119,10 +123,12 @@ def plot_scatter(fig, x: np.ndarray, y: np.ndarray, label: str):
         Returns the function itself for a smaller (n-1) float-array (y) until it is an
         1D-array.
     """
-    fig.scatter(x, y[:, 0], label=label)
-    if y.shape[1] == 1:
-        return fig
-    return plot_scatter(fig, x, y[:, 1:], label=label)
+    if len(y.shape) > 1:
+        for i in range(y.shape[1]):
+            fig.scatter(x, y[:, i], label=label)
+    else:
+        fig.scatter(x, y, label=label)
+    return fig
 
 
 def fig_size(width: float, height: float) -> Any:
@@ -146,7 +152,7 @@ def fig_size(width: float, height: float) -> Any:
     return fig
 
 
-def plot(data: np.ndarray, args: dict, label: str) -> None:
+def plot(data: np.ndarray, args: Dict[str, Any], label: str) -> None:
     """Generate the plots as classical or scatter plots.
 
     plot() is generating the classical or scatter plots according to the arguments
@@ -156,7 +162,7 @@ def plot(data: np.ndarray, args: dict, label: str) -> None:
     ----------
     data : float-array
         2D-Numpy-array with `dtype=float`.
-    args : dict
+    args : Dict[str, Any]
         Dictionary of the keywords and values from the parser.
     label : str
         The label of the scatter-plot(s) is the current filename.
@@ -197,7 +203,7 @@ def plot(data: np.ndarray, args: dict, label: str) -> None:
         sys.exit(1)
 
 
-def bashplot(fnames: str, args: dict) -> Any:
+def bashplot(fnames: str, args: Dict[str, Any]) -> Any:
     """bashplot.
 
     bashplot() is plotting each file independently according to the args. For a
@@ -208,7 +214,7 @@ def bashplot(fnames: str, args: dict) -> Any:
     ----------
     fnames : str-list
         List of the filename(s); is always a list even if single value included.
-    args : dict
+    args : Dict[str, Any]
         Dictionary of the keywords and values from the parser.
 
     Returns
@@ -225,17 +231,17 @@ def bashplot(fnames: str, args: dict) -> Any:
         return bashplot(fnames[1:], args)
 
 
-def get_args(opt: dict = None) -> dict:
+def get_args(opt: Optional[Dict[str, Any]] = None) -> Dict[str, Any]:
     """Get the parser arguments from the command line.
 
     Parameters
     ----------
-    opt : dict, optional
+    opt : Dict[str, Any], optional
         Optional Dictionary for modifying the parser arguments; default is None.
 
     Returns
     -------
-    args : dict
+    args : Dict[str, Any]
         Dictionary of the keywords and values from the parser.
     """
     parser = argparse.ArgumentParser(
